spannertools.TrillSpanner
=========================

.. abjad-lineage:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner

.. autoclass:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.written_duration
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pitch
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.written_pitch
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__repr__
   :noindex:
